@@ -2,14 +2,13 @@ import concurrent.futures
 import os
 import pickle
 from array import array
-from contextlib import nullcontext
 from functools import partial
 from glob import glob
 from itertools import permutations
 from pathlib import Path
 from unittest.mock import call, patch
 
-import numpy as np
+import numpy
 import pytest
 from numpy.testing import assert_almost_equal, assert_array_equal
 
@@ -19,13 +18,7 @@ from pyproj.datadir import append_data_dir
 from pyproj.enums import TransformDirection
 from pyproj.exceptions import ProjError
 from pyproj.transformer import AreaOfInterest, TransformerGroup
-from test.conftest import (
-    PROJ_GTE_91,
-    PROJ_GTE_92,
-    grids_available,
-    proj_env,
-    proj_network_env,
-)
+from test.conftest import grids_available, proj_env, proj_network_env
 
 
 def test_tranform_wgs84_to_custom():
@@ -64,8 +57,8 @@ def test_illegal_transformation():
         xx, yy = pyproj.transform(
             p1, p2, (-180, -180, 180, 180, -180), (-90, 90, 90, -90, -90)
         )
-    assert np.all(np.isinf(xx))
-    assert np.all(np.isinf(yy))
+    assert numpy.all(numpy.isinf(xx))
+    assert numpy.all(numpy.isinf(yy))
     with pytest.warns(FutureWarning), pytest.raises(ProjError):
         pyproj.transform(
             p1, p2, (-180, -180, 180, 180, -180), (-90, 90, 90, -90, -90), errcheck=True
@@ -239,8 +232,9 @@ def test_2d_with_time_itransform_original_crs_obs2():
 
 
 def test_itransform_time_3rd_invalid():
-    with pytest.warns(FutureWarning), pytest.raises(
-        ValueError, match="'time_3rd' is only valid for 3 coordinates."
+    with (
+        pytest.warns(FutureWarning),
+        pytest.raises(ValueError, match="'time_3rd' is only valid for 3 coordinates."),
     ):
         list(
             itransform(
@@ -250,8 +244,9 @@ def test_itransform_time_3rd_invalid():
                 time_3rd=True,
             )
         )
-    with pytest.warns(FutureWarning), pytest.raises(
-        ValueError, match="'time_3rd' is only valid for 3 coordinates."
+    with (
+        pytest.warns(FutureWarning),
+        pytest.raises(ValueError, match="'time_3rd' is only valid for 3 coordinates."),
     ):
         list(itransform(7789, 8401, [(3496737.2679, 743254.4507)], time_3rd=True))
 
@@ -412,7 +407,7 @@ def test_always_xy__itransform():
         )
 
 
-@pytest.mark.parametrize("empty_array", [(), [], np.array([])])
+@pytest.mark.parametrize("empty_array", [(), [], numpy.array([])])
 def test_transform_empty_array_xy(empty_array):
     transformer = Transformer.from_crs(2193, 4326)
     assert_array_equal(
@@ -420,7 +415,7 @@ def test_transform_empty_array_xy(empty_array):
     )
 
 
-@pytest.mark.parametrize("empty_array", [(), [], np.array([])])
+@pytest.mark.parametrize("empty_array", [(), [], numpy.array([])])
 def test_transform_empty_array_xyzt(empty_array):
     transformer = Transformer.from_pipeline("+init=ITRF2008:ITRF2000")
     assert_array_equal(
@@ -521,45 +516,14 @@ def test_str():
     assert str(Transformer.from_crs(4326, 3857)).startswith("proj=pipeline")
 
 
-@pytest.mark.parametrize(
-    "from_crs, to_crs, expected_repr",
-    [
-        (
-            7789,
-            8401,
-            (
-                "<Transformation Transformer: helmert>\n"
-                "Description: ITRF2014 to ETRF2014 (2)\n"
-                "Area of Use:\n"
-                "- name: Europe - onshore and offshore: Albania; Andorra; Austria; "
-                "Belgium; Bosnia and Herzegovina; Bulgaria; Croatia; Cyprus; Czechia; "
-                "Denmark; Estonia; Faroe Islands; Finland; France; Germany; Gibraltar; "
-                "Greece; Hungary; Ireland; Italy; Kosovo; Latvia; Liechtenstein; "
-                "Lithuania; Luxembourg; Malta; Moldova; Monaco; Montenegro; "
-                "Netherlands; North Macedonia; "
-                "Norway including Svalbard and Jan Mayen; "
-                "Poland; Portugal; Romania; San Marino; Serbia; Slovakia; Slovenia; "
-                "Spain; Sweden; Switzerland; "
-                "United Kingdom (UK) including Channel Islands and Isle of Man; "
-                "Vatican City State.\n"
-                "- bounds: (-16.1, 32.88, 40.18, 84.73)"
-            ),
-        ),
-        (
-            4326,
-            3857,
-            (
-                "<Conversion Transformer: pipeline>\n"
-                "Description: Popular Visualisation Pseudo-Mercator\n"
-                "Area of Use:\n"
-                "- name: World.\n"
-                "- bounds: (-180.0, -90.0, 180.0, 90.0)"
-            ),
-        ),
-    ],
-)
-def test_repr(from_crs, to_crs, expected_repr):
-    assert repr(Transformer.from_crs(from_crs, to_crs)) == expected_repr
+def test_repr():
+    assert repr(Transformer.from_crs(4326, 3857)) == (
+        "<Conversion Transformer: pipeline>\n"
+        "Description: Popular Visualisation Pseudo-Mercator\n"
+        "Area of Use:\n"
+        "- name: World.\n"
+        "- bounds: (-180.0, -90.0, 180.0, 90.0)"
+    )
 
 
 @pytest.mark.grid
@@ -571,14 +535,6 @@ def test_repr__conditional():
             "Description: unavailable until proj_trans is called\n"
             "Area of Use:\n- undefined"
         )
-    elif PROJ_GTE_92:
-        assert trans_repr == (
-            "<Unknown Transformer: noop>\n"
-            "Description: Transformation from EGM2008 height to WGS 84 "
-            "(ballpark vertical transformation, without ellipsoid height "
-            "to vertical height correction)\n"
-            "Area of Use:\n- undefined"
-        )
     else:
         assert trans_repr == (
             "<Other Coordinate Operation Transformer: noop>\n"
@@ -586,7 +542,7 @@ def test_repr__conditional():
             "(ballpark vertical transformation, without ellipsoid height "
             "to vertical height correction)\n"
             "Area of Use:\n"
-            "- name: World\n"
+            "- name: World.\n"
             "- bounds: (-180.0, -90.0, 180.0, 90.0)"
         )
 
@@ -636,8 +592,7 @@ def test_transformer__operations__scope_remarks():
     assert transformer.scope is None
     assert [op.scope for op in transformer.operations] == [
         "Engineering survey, topographic mapping.",
-        "Transformation of GDA94 coordinates that have been derived "
-        "through GNSS CORS.",
+        "Transformation of GDA94 coordinates that have been derived through GNSS CORS.",
         "Engineering survey, topographic mapping.",
     ]
     assert [str(op.remarks)[:5].strip() for op in transformer.operations] == [
@@ -649,16 +604,13 @@ def test_transformer__operations__scope_remarks():
 
 @pytest.mark.grid
 def test_transformer__only_best():
-    with nullcontext() if PROJ_GTE_92 else pytest.raises(
-        NotImplementedError, match="only_best requires PROJ 9.2"
-    ):
-        transformer = Transformer.from_crs(4326, 2964, only_best=True)
-        if not grids_available("ca_nrc_ntv2_0.tif"):
-            with pytest.raises(
-                ProjError,
-                match="Grid ca_nrc_ntv2_0.tif is not available.",
-            ):
-                transformer.transform(60, -100, errcheck=True)
+    transformer = Transformer.from_crs(4326, 2964, only_best=True)
+    if not grids_available("ca_nrc_ntv2_0.tif"):
+        with pytest.raises(
+            ProjError,
+            match="Grid ca_nrc_ntv2_0.tif is not available.",
+        ):
+            transformer.transform(60, -100, errcheck=True)
 
 
 def test_transformer_group():
@@ -775,14 +727,7 @@ def test_transformer_group__get_transform_crs():
     if grids_available(
         "nl_nsgi_nlgeo2018.tif", "nl_nsgi_rdtrans2018.tif", check_all=True
     ):
-        if PROJ_GTE_91:
-            assert len(tg.transformers) == 2
-        else:
-            assert len(tg.transformers) == 6
-    elif not PROJ_GTE_91 and grids_available("nl_nsgi_rdtrans2018.tif"):
         assert len(tg.transformers) == 2
-    elif not PROJ_GTE_91 and grids_available("nl_nsgi_nlgeo2018.tif"):
-        assert len(tg.transformers) == 4
     else:
         assert len(tg.transformers) == 1
 
@@ -791,7 +736,7 @@ def test_transformer__area_of_interest():
     transformer = Transformer.from_crs(
         "EPSG:7789",
         "EPSG:4936",
-        area_of_interest=AreaOfInterest(-177.25, -44.64, -43.3, -175.54),
+        area_of_interest=AreaOfInterest(-177.25, -44.64, -175.54, -43.3),
     )
     assert (
         transformer.description
@@ -803,7 +748,7 @@ def test_transformer_proj__area_of_interest():
     transformer = Transformer.from_proj(
         "EPSG:7789",
         "EPSG:4936",
-        area_of_interest=AreaOfInterest(-177.25, -44.64, -43.3, -175.54),
+        area_of_interest=AreaOfInterest(-177.25, -44.64, -175.54, -43.3),
     )
     assert (
         transformer.description
@@ -1076,9 +1021,10 @@ def test_transformer_group__download_grids(get_user_data_dir_mock, tmp_path, cap
                 "Downloading: https://cdn.proj.org/ca_nrc_ntv2_0.tif\n"
             )
         # make sure not downloaded again
-        with proj_env(), patch(
-            "pyproj.transformer._download_resource_file"
-        ) as download_mock:
+        with (
+            proj_env(),
+            patch("pyproj.transformer._download_resource_file") as download_mock,
+        ):
             append_data_dir(str(tmp_path))
             trans_group = TransformerGroup(4326, 2964)
             trans_group.download_grids()
@@ -1140,9 +1086,6 @@ def test_transformer_group__download_grids__directory(
             )
 
 
-@pytest.mark.skipif(
-    pyproj._datadir._USE_GLOBAL_CONTEXT, reason="Global Context not Threadsafe."
-)
 def test_transformer_multithread__pipeline():
     # https://github.com/pyproj4/pyproj/issues/782
     trans = Transformer.from_pipeline(
@@ -1158,9 +1101,6 @@ def test_transformer_multithread__pipeline():
             pass
 
 
-@pytest.mark.skipif(
-    pyproj._datadir._USE_GLOBAL_CONTEXT, reason="Global Context not Threadsafe."
-)
 def test_transformer_multithread__crs():
     # https://github.com/pyproj4/pyproj/issues/782
     trans = Transformer.from_crs(4326, 3857)
@@ -1236,7 +1176,7 @@ def test_transform_bounds_densify(density, expected):
         "+proj=laea +lat_0=45 +lon_0=-100 +x_0=0 +y_0=0 "
         "+a=6370997 +b=6370997 +units=m +no_defs",
     )
-    assert np.allclose(
+    assert numpy.allclose(
         transformer.transform_bounds(40, -120, 64, -80, densify_pts=density),
         expected,
     )
@@ -1253,7 +1193,15 @@ def test_transform_bounds_densify(density, expected):
     "input_bounds, radians",
     [
         ((-120, 40, -80, 64), False),
-        ((np.radians(-120), np.radians(40), np.radians(-80), np.radians(64)), True),
+        (
+            (
+                numpy.radians(-120),
+                numpy.radians(40),
+                numpy.radians(-80),
+                numpy.radians(64),
+            ),
+            True,
+        ),
     ],
 )
 def test_transform_bounds_densify__xy(density, expected, input_bounds, radians):
@@ -1263,7 +1211,7 @@ def test_transform_bounds_densify__xy(density, expected, input_bounds, radians):
         "+a=6370997 +b=6370997 +units=m +no_defs",
         always_xy=True,
     )
-    assert np.allclose(
+    assert numpy.allclose(
         transformer.transform_bounds(
             *input_bounds, densify_pts=density, radians=radians
         ),
@@ -1362,27 +1310,6 @@ def test_transform_bounds__beyond_global_bounds():
     )
 
 
-@pytest.mark.parametrize(
-    "input_crs,input_bounds,expected_bounds",
-    [
-        (
-            "ESRI:102036",
-            (-180.0, -90.0, 180.0, 1.3 if PROJ_GTE_92 else 0),
-            (0, -116576599 if PROJ_GTE_92 else -89178008, 0, 0),
-        ),
-        ("ESRI:54026", (-180.0, -90.0, 180.0, 90.0), (0, -179545824, 0, 179545824)),
-    ],
-)
-def test_transform_bounds__ignore_inf(input_crs, input_bounds, expected_bounds):
-    crs = CRS(input_crs)
-    transformer = Transformer.from_crs(crs.geodetic_crs, crs, always_xy=True)
-    assert_almost_equal(
-        transformer.transform_bounds(*input_bounds),
-        expected_bounds,
-        decimal=0,
-    )
-
-
 def test_transform_bounds__ignore_inf_geographic():
     crs_wkt = (
         'PROJCS["Interrupted_Goode_Homolosine",'
@@ -1490,8 +1417,8 @@ def test_transform_bounds__south_pole__xy():
 
 @pytest.mark.parametrize("inplace", [True, False])
 def test_transform__fortran_order(inplace):
-    lons, lats = np.arange(-180, 180, 20), np.arange(-90, 90, 10)
-    lats, lons = np.meshgrid(lats, lons)
+    lons, lats = numpy.arange(-180, 180, 20), numpy.arange(-90, 90, 10)
+    lats, lons = numpy.meshgrid(lats, lons)
     f_lons, f_lats = lons.copy(order="F"), lats.copy(order="F")
     transformer = Transformer.from_crs(
         "EPSG:4326",
@@ -1550,10 +1477,10 @@ def test_4d_transform__inplace__array__int():
 
 def test_4d_transform__inplace__numpy():
     transformer = Transformer.from_crs(7789, 8401)
-    xarr = np.array([3496737.2679], dtype=np.float64)
-    yarr = np.array([743254.4507], dtype=np.float64)
-    zarr = np.array([5264462.9620], dtype=np.float64)
-    tarr = np.array([2019.0], dtype=np.float64)
+    xarr = numpy.array([3496737.2679], dtype=numpy.float64)
+    yarr = numpy.array([743254.4507], dtype=numpy.float64)
+    zarr = numpy.array([5264462.9620], dtype=numpy.float64)
+    tarr = numpy.array([2019.0], dtype=numpy.float64)
     t_xarr, t_yarr, t_zarr, t_tarr = transformer.transform(
         xx=xarr, yy=yarr, zz=zarr, tt=tarr, inplace=True
     )
@@ -1569,10 +1496,10 @@ def test_4d_transform__inplace__numpy():
 
 def test_4d_transform__inplace__numpy__int():
     transformer = Transformer.from_crs(7789, 8401)
-    xarr = np.array([3496737], dtype=np.int32)
-    yarr = np.array([743254], dtype=np.int32)
-    zarr = np.array([5264462], dtype=np.int32)
-    tarr = np.array([2019], dtype=np.int32)
+    xarr = numpy.array([3496737], dtype=numpy.int32)
+    yarr = numpy.array([743254], dtype=numpy.int32)
+    zarr = numpy.array([5264462], dtype=numpy.int32)
+    tarr = numpy.array([2019], dtype=numpy.int32)
     t_xarr, t_yarr, t_zarr, t_tarr = transformer.transform(
         xx=xarr, yy=yarr, zz=zarr, tt=tarr, inplace=True
     )
@@ -1651,6 +1578,12 @@ def test_transformer_group_allow_ballpark_filter():
     assert not group.unavailable_operations
 
 
+def test_transformer_group_allow_superseded_filter():
+    default_group = TransformerGroup(4203, 4326)
+    superseded_group = TransformerGroup(4203, 4326, allow_superseded=True)
+    assert len(superseded_group.transformers) > len(default_group.transformers)
+
+
 def test_transformer_group_authority_filter():
     group = TransformerGroup("EPSG:4326", "EPSG:4258", authority="PROJ")
     assert len(group.transformers) == 1
@@ -1686,22 +1619,15 @@ def test_transformer_force_over():
 
 def test_transformer__get_last_used_operation():
     transformer = Transformer.from_crs("EPSG:4326", "EPSG:3857")
-    if PROJ_GTE_91:
-        with pytest.raises(
-            ProjError,
-            match=(
-                r"Last used operation not found\. "
-                r"This is likely due to not initiating a transform\."
-            ),
-        ):
-            transformer.get_last_used_operation()
-        xxx, yyy = transformer.transform(1, 2)
-        operation = transformer.get_last_used_operation()
-        assert isinstance(operation, Transformer)
-        assert xxx, yyy == operation.transform(1, 2)
-    else:
-        with pytest.raises(
-            NotImplementedError,
-            match=r"PROJ 9\.1\+ required to get last used operation\.",
-        ):
-            transformer.get_last_used_operation()
+    with pytest.raises(
+        ProjError,
+        match=(
+            r"Last used operation not found\. "
+            r"This is likely due to not initiating a transform\."
+        ),
+    ):
+        transformer.get_last_used_operation()
+    xxx, yyy = transformer.transform(1, 2)
+    operation = transformer.get_last_used_operation()
+    assert isinstance(operation, Transformer)
+    assert xxx, yyy == operation.transform(1, 2)
